[−][src]Crate wasm_logger
A simple logger for front end wasm web app.
Please see README for documentation.
Structs
| Config | Specify what to be logged |
Enums
| MessageLocation | Specify where the message will be logged. |
Functions
| init | Initialize the logger which the given config. If failed, it will log a message to the the browser console. |